@@ -1,9 +1,9 @@
-from datetime import datetime, timedelta
+from datetime import datetime
 from typing import Dict
 
 import jwt
 
-# taken from https://github.com/Humanitec/django-oauth-toolkit-jwt
+
 # taken from https://github.com/Humanitec/django-oauth-toolkit-jwt
 def generate_payload(issuer: str, expiration: datetime, **extra_data) -> Dict[str, str]:
     """
@@ -38,3 +38,13 @@ def encode_jwt(payload: Dict[str, str], algorithm: str, private_key: str, header
 
     encoded = jwt.encode(payload, private_key, algorithm=algorithm, headers=headers)
     return encoded
+
+
+def decode_jwt_claims_without_verification(token: str):
+    decoded_claims = jwt.decode(token, options={"verify_signature": False})
+    return decoded_claims
+
+
+def decode_jwt_header_without_verification(token: str):
+    decoded_header = jwt.get_unverified_header(token)
+    return decoded_header
